@@ -32,7 +32,7 @@ translate_formula <- function(f) {
       as.character(vars)
     }
   )
-  body_sql <- dbplyr::translate_sql(!!f[[2]])
+  body_sql <- dbplyr::translate_sql(!!f[[2]], con = dbplyr::simulate_hive())
   lambda <- dbplyr::sql(paste(params_sql, "->", body_sql))
 
   lambda
@@ -115,7 +115,7 @@ process_dest_col <- function(expr, dest_col) {
     c(sep = ",") %>%
     do.call(paste, .)
 
-  body_sql <- dbplyr::translate_sql(...)
+  body_sql <- dbplyr::translate_sql(..., con = dbplyr::simulate_hive())
 
   lambda <- dbplyr::sql(paste(params_sql, "->", body_sql))
   class(lambda) <- c(class(lambda), "spark_sql_lambda")
@@ -168,7 +168,7 @@ hof_transform <- function(
 
   sql <- paste(
     "TRANSFORM(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
@@ -208,7 +208,7 @@ hof_filter <- function(x, func, expr = NULL, dest_col = NULL, ...) {
 
   sql <- paste(
     "FILTER(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
@@ -265,9 +265,9 @@ hof_aggregate <- function(
 
   sql <- do.call(paste, as.list(c(
     "AGGREGATE(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
-    as.character(dbplyr::translate_sql(!!rlang::enexpr(start))),
+    as.character(dbplyr::translate_sql(!!rlang::enexpr(start), con = dbplyr::simulate_hive())),
     ",",
     as.character(merge),
     if (identical(finish, NULL)) NULL else c(",", as.character(finish)),
@@ -299,7 +299,7 @@ hof_exists <- function(x, pred, expr = NULL, dest_col = NULL, ...) {
 
   sql <- paste(
     "EXISTS(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(pred),
     ")"
@@ -362,9 +362,9 @@ hof_zip_with <- function(
 
   sql <- paste(
     "ZIP_WITH(",
-    as.character(dbplyr::translate_sql(!!left)),
+    as.character(dbplyr::translate_sql(!!left, con = dbplyr::simulate_hive())),
     ",",
-    as.character(dbplyr::translate_sql(!!right)),
+    as.character(dbplyr::translate_sql(!!right, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
@@ -418,7 +418,7 @@ hof_array_sort <- function(
 
   sql <- paste(
     "ARRAY_SORT(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
@@ -464,7 +464,7 @@ hof_map_filter <- function(
 
   sql <- paste(
     "MAP_FILTER(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
@@ -515,7 +515,7 @@ hof_forall <- function(
 
   sql <- paste(
     "FORALL(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(pred),
     ")"
@@ -560,7 +560,7 @@ hof_transform_keys <- function(
 
   sql <- paste(
     "TRANSFORM_KEYS(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
@@ -605,7 +605,7 @@ hof_transform_values <- function(
 
   sql <- paste(
     "TRANSFORM_VALUES(",
-    as.character(dbplyr::translate_sql(!!expr)),
+    as.character(dbplyr::translate_sql(!!expr, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
@@ -681,9 +681,9 @@ hof_map_zip_with <- function(
 
   sql <- paste(
     "MAP_ZIP_WITH(",
-    as.character(dbplyr::translate_sql(!!map1)),
+    as.character(dbplyr::translate_sql(!!map1, con = dbplyr::simulate_hive())),
     ",",
-    as.character(dbplyr::translate_sql(!!map2)),
+    as.character(dbplyr::translate_sql(!!map2, con = dbplyr::simulate_hive())),
     ",",
     as.character(func),
     ")"
