@@ -16,15 +16,18 @@ spark_install_version_expand <- function(version, installed_only) {
     versions <- spark_available_versions(show_minor = TRUE)$spark
   }
 
-  versions <- versions[grepl(version, versions)]
+  sub_versions <- substr(versions, 1, nchar(version))
+
+  versions <- versions[version == sub_versions]
 
   if (length(versions) > 0) {
-    sort(versions, decreasing = TRUE)[1]
+    out <- sort(versions, decreasing = TRUE)[1]
   } else {
     # If the version specified is not a known available version, then don't
     # attempt to exapnd it.
-    version
+    out <- version
   }
+  out
 }
 
 #' Find a given Spark installation by version.
