@@ -115,7 +115,7 @@ sdf_unnest_longer <- function(
                     "%s.%s, %s",
                     col_sql_name,
                     quote_sql_name(x),
-                    dbplyr::escape(x, con = dbplyr::simulate_dbi())
+                    dbplyr::escape(x, con = dbplyr::simulate_hive())
                   )
                 }
               ) %>%
